from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.arm.base_resource_check import BaseResourceCheck


class AzureInstancePassword(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Azure Instance does not use basic authentication(Use SSH Key Instead)"
        id = "CKV_AZURE_1"
        supported_resources = ['Microsoft.Compute/virtualMachines']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if "properties" in conf:
            if "storageProfile" in conf["properties"]:
                if "imageReference" in conf["properties"]["storageProfile"]:
                    if "publisher" in conf["properties"]["storageProfile"]["imageReference"]:
                        if "windows" in conf["properties"]["storageProfile"]["imageReference"]["publisher"].lower():
                            # This check is not relevant to Windows systems
                            return CheckResult.PASSED

            if "osProfile" in conf["properties"]:
                if "linuxConfiguration" in conf["properties"]["osProfile"]:
                    if conf["properties"]["osProfile"]["linuxConfiguration"] != None and \
                            "disablePasswordAuthentication" in conf["properties"]["osProfile"]["linuxConfiguration"]:
                        if str(conf["properties"]["osProfile"]["linuxConfiguration"]["disablePasswordAuthentication"]).lower() == "true":
                            return CheckResult.PASSED
        return CheckResult.FAILED

check = AzureInstancePassword()



from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class AKSRbacEnabled(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure RBAC is enabled on AKS clusters"
        id = "CKV_AZURE_5"
        supported_resources = ['azurerm_kubernetes_cluster']
        categories = [CheckCategories.KUBERNETES]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'role_based_access_control/[0]/enabled/[0]'


check = AKSRbacEnabled()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.arm.base_resource_check import BaseResourceCheck

# https://docs.microsoft.com/en-us/azure/templates/microsoft.web/2019-08-01/sites
# clientCertEnabled default = false

class AppServiceClientCertificate(BaseResourceCheck):
    def __init__(self):
        name = "Ensure the web app has 'Client Certificates (Incoming client certificates)' set"
        id = "CKV_AZURE_17"
        supported_resources = ['Microsoft.Web/sites']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if "properties" in conf:
            if "clientCertEnabled" in conf["properties"]:
                if str(conf["properties"]["clientCertEnabled"]).lower() == "true":
                    return CheckResult.PASSED
        return CheckResult.FAILED

check = AppServiceClientCertificate()


from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
import json
import re


class IAMRoleAllowAssumeFromAccount(BaseResourceCheck):

    def __init__(self):
        name = "Ensure IAM role allows only specific principals in account to assume it"
        id = "CKV_AWS_61"
        supported_resources = ['aws_iam_role']
        categories = [CheckCategories.IAM]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if isinstance(conf['assume_role_policy'][0], str):
            try:
                assume_role_block = json.loads(conf['assume_role_policy'][0])
                if 'Statement' in assume_role_block.keys():
                    if 'Principal' in assume_role_block['Statement'][0]:
                        if 'AWS' in assume_role_block['Statement'][0]['Principal']:
                            account_access = re.compile(r'\d{12}|arn:aws:iam::\d{12}:root')
                            if re.match(account_access, assume_role_block['Statement'][0]['Principal']['AWS']):
                                return CheckResult.FAILED
            except: # nosec
                pass
        return CheckResult.PASSED


check = IAMRoleAllowAssumeFromAccount()
